@@ -16,11 +16,22 @@ from importlib import import_module
 import errno
 import gzip
 import os
+import shutil
 import uuid
 
 
 # -- Datetime -----------------------------------------------------------------
 
+def current_time() -> str:
+    """Get ISO format string for the current time.
+
+    Returns
+    -------
+    str
+    """
+    return utc_now().isoformat()
+
+
 def to_datetime(timestamp):
     """Converts a timestamp string in ISO format into a datatime object in
     UTC timezone.
@@ -93,6 +104,22 @@ def import_obj(import_path):
 
 # -- I/O ----------------------------------------------------------------------
 
+def cleardir(directory):
+    """Remove all files in the given directory.
+
+    Parameters
+    ----------
+    directory: string
+        Path to directory that is being created.
+    """
+    for filename in os.listdir(directory):
+        file = os.path.join(directory, filename)
+        if os.path.isfile(file) or os.path.islink(file):
+            os.unlink(file)
+        elif os.path.isdir(file):
+            shutil.rmtree(file)
+
+
 def createdir(directory, abs=False):
     """Safely create the given directory path if it does not exist.
 
